@@ -21,10 +21,10 @@
 
 #' @describeIn set_token set the environment variable `SPECIESPLUS_TOKEN`.
 set_token <- function(token = NULL) {
-    if (is.null(token)) 
+    if (is.null(token))
         token <- readline("Enter your token without quotes: ")
     if (identical(token, "")) {
-        message("no token provided")
+        stop("No token has been provided.")
     } else {
         Sys.setenv(SPECIESPLUS_TOKEN = token)
         cat("Authentication token stored for the session.\n")
